@@ -10,22 +10,23 @@ MojoMojo::Controller::Tag - Tags controller
 
 =head1 SYNOPSIS
 
-Handles urls like
-  /.recent/macro
-  /.list/flooobs
-  /.recent/flood
+Handles the following URLs
+  /.tags/
+  /.list/<tag>  (dispatched from Page)
+  /.recent/<tag>  (dispatched from Page)
 
 =head1 DESCRIPTION
 
-This controller handles tag-related actions
+This controller generates a tag cloud and retrieves (all or recent) pages
+tagged with a given tag.
 
 =head1 ACTIONS
 
 =head2 list
 
-This is a private action, and is dispatched from /.list when it's
-supplied with a tag argument. it will list all pages belonging
-to a certain tag.
+This is a private action, and is dispatched from
+L</.list|MojoMojo::Controller::Page/list> when supplied with a tag
+argument. It will list all pages tagged with the given tag.
 
 =cut
 
@@ -42,9 +43,9 @@ sub list : Private {
 
 =head2 recent
 
-This is a private action, and is dispatched from C</.recent> when it's
-supplied with a tag argument. It will list recent pages belonging
-to a certain tag.
+This is a private action, and is dispatched from
+L</.recent|MojoMojo::Controller::Page/recent> when supplied with a tag
+argument. It will list recent pages tagged with the given tag.
 
 =cut
 
@@ -72,8 +73,11 @@ sub tags : Global {
     }@$tags;
     my $cloud = HTML::TagCloud->new();
     foreach my $tag (keys %tags) {
-    	$cloud->add($tag, $c->req->base . $c->stash->{path} . '.list/' . $tag,
-            $tags{$tag});
+        $cloud->add(
+            $tag, 
+            $c->req->base . $c->stash->{path} . '.list/' . $tag,
+            $tags{$tag}
+        );
     }
     $c->stash->{cloud}    = $cloud;
     $c->stash->{template} = 'tag/cloud.tt';
