@@ -85,7 +85,7 @@ Show a list of the active users with links to the pages they edited.
 =cut
 
 sub users : Global {
-    my ( $elf, $c, $tag ) = @_;
+    my ( $elf, $c ) = @_;
     my $res = $c->model("DBIC::Person")->search(
         { active => 1 },
         {
@@ -99,6 +99,12 @@ sub users : Global {
     $c->stash->{template} = 'user/list.tt';
 }
 
+=head2 page_user
+
+Show a user's preferences
+
+=cut
+
 sub page_user : Private {
     my ( $self, $c ) = @_;
     my $user = $c->stash->{user};
@@ -175,6 +181,12 @@ sub password : Path('/prefs/password') FormConfig {
     }
 }
 
+=head2 recover_pass
+
+Email a user a new password
+
+=cut
+
 sub recover_pass : Global {
     my ( $self, $c ) = @_;
     return unless ( $c->req->method eq 'POST' );
@@ -275,6 +287,12 @@ sub register : Global FormConfig {
     }
 }
 
+=head2 is_account_taken
+
+Test to see if a login or email is already in use.
+
+=cut
+
 sub is_account_taken : Private {
     my ( $self, $c ) = @_;
 
@@ -399,6 +417,12 @@ sub profile : Global {
     }
 }
 
+=head2 editprofile
+
+Form to edit a person's profile
+
+=cut
+
 sub editprofile : Global FormConfig {
     my ( $self, $c ) = @_;
     my $form = $c->stash->{form};
@@ -429,6 +453,12 @@ sub editprofile : Global FormConfig {
 
 }
 
+=head2 do_editprofile
+
+Apply the edits to a person's profile
+
+=cut
+
 sub do_editprofile : Global {
     my ( $self, $c ) = @_;
     $c->form(
