@@ -8,6 +8,13 @@ eval {
     require LWP::Simple;  # LWP::Simple is indeed required, and URI::Fetch doesn't depend on it
 };
 my $dependencies_installed = !$@;
+
+=head2 module_loaded
+
+Return true if the module is loaded.
+
+=cut
+
 sub module_loaded { $dependencies_installed }
 
 our $VERSION = '0.01';
@@ -73,7 +80,7 @@ sub include {
     my $rel = $url->rel( $c->req->base );
     if (not $rel->scheme) {
         # if so, then return the inline version of the page is requests
-        return $c->subreq( '/inline', { path => $rel.'' eq './' ? '/' : '/'.$rel } );
+        return $c->subreq( ($rel.'' eq './' ? '/' : '/'.$rel).'.inline'  );
     }
     my $res = URI::Fetch->fetch( $url, Cache => $c->cache );
     return $res->content if defined $res;
