@@ -26,9 +26,15 @@ hashes for any pages at the end of the path that do not exist. All paths
 include the root (/), which must exist, so a path of at least one element
 will always be returned.
 
-The "proto page" hash keys are:
+The "proto page" hash keys are shown in the example below, where we assume
+that C</blog> exists and C</blog/My_New_Entry> doesn't exist yet:
 
-TODO
+    {
+        depth => 2,
+        name => "my_new_entry",
+        name_orig => "My_New_Entry",
+        path => "/blog/My_New_Entry",
+    },
 
 =cut
 
@@ -398,6 +404,13 @@ sub open_gap {
 }
 
 # XXX: Update index_page (Model::Search)
+
+=head2 create_page
+
+Create a new page in the wiki.
+
+=cut
+
 sub create_page {
   my ($self,$url, $body, $person) = @_;
 
